#!/bin/bash
# packager          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage			: http://dvdauthor.sourceforge.net/
# source location	: http://downloads.sourceforge.net/dvdauthor/dvdauthor-0.6.14.tar.gz
# dependency        : 
# last revised      : 22.09.2009

softname='dvdauthor'
softversion='0.6.14'
packageversion='1fb'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://downloads.sourceforge.net/dvdauthor/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slac-desc
cat <<EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
dvdauthor: dvdauthor (A simple set of tools to help you author a DVD)
dvdauthor:
dvdauthor: dvdauthor is a program that will generate a DVD movie from a 
dvdauthor: valid mpeg2 stream.
dvdauthor:
dvdauthor: The resulting movie should play in a standard DVD player.
dvdauthor:
dvdauthor: 
dvdauthor:
dvdauthor: 
dvdauthor: 
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
    --prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var \
    --bindir=/usr/bin \
    --libdir=/usr/lib \
    --includedir=/usr/include \
    --mandir=/usr/man \
    --program-prefix="" \
    --program-suffix="" \
    --build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest
   
# add 'default' files
cp -a \
   AUTHORS COPYING ChangeLog INSTALL NEWS README TODO\
   $dest/usr/doc/$softname-$softversion

# strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# SalixBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
echo -e "bzip2,e2fsprogs,expat,fontconfig,freetype,fribidi,gcc,\
imagemagick,lcms,libICE,libSM,libX11,libXau,libXdmcp,libXext,\
libXt,libdvdread,libjpeg,libpng,libtiff,libxcb,libxml2,zlib" > $package.dep

# .src
rm -rf $src
rm -rf $dest

# erase
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/ap/dvdauthor/build-dvdauthor.sh > $package.src
echo $source >>$package.src

# log
) 2>&1 | tee "$softname-$softversion-build.log"
